# parts

|   |   |   |   |   |   |   |   |   |   |
| --- | --- | --- | --- | --- | --- | --- | --- | --- | --- |
| [`12 VDC motor, 20-45 W`](../parts/dc-motor-12-VDC-45W.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/gearbox1.jpg?raw=true)](../parts/dc-motor-12-VDC-45W.md)  | [`16 AWG wire`](../parts/16-awg-wire.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/16-awg-wire.jpeg?raw=true)](../parts/16-awg-wire.md)  | [`1N4148 diode`](../parts/1N4148.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/TVSdiode.png?raw=true)](../parts/1N4148.md)  | [`2 x AA battery holder`](../parts/2xAA-battery-holder.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/2xAA-battery-holder.jpg?raw=true)](../parts/2xAA-battery-holder.md)  | [`220VAC dimmer`](../parts/220VAC-dimmer.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/220VAC-dimmer.jpeg?raw=true)](../parts/220VAC-dimmer.md)  | [`36V DC hub motor, 350 W, front, no gearbox`](../parts/36v-hub-motor.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/36v-hub-motor.jpg?raw=true)](../parts/36v-hub-motor.md)  | [`4 x AA battery holder`](../parts/4xAA-battery-holder.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/4xAA-battery-holder.jpg?raw=true)](../parts/4xAA-battery-holder.md)  | [`4-channel transmitter and receiver`](../parts/4-ch-transceiver.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/4-channel-remote-control.png?raw=true)](../parts/4-ch-transceiver.md)  | [`43 A, H-Bridge Motor Driver`](../parts/BTS7960.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/bts7960.jpg?raw=true)](../parts/BTS7960.md)  | [`433 MHz SMA whip antenna (small stubby or ~10–20 cm) or U.FL -> SMA pigtail if the module has a tiny U.FL connector.`](../parts/whip-antenna.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/whip-antenna.jpeg?raw=true)](../parts/whip-antenna.md)  |
| [`5V unmanaged 10/100 switch`](../parts/5v-unmanaged-10-100-switch.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/5v-unmanaged-10-100-switch.jpg?raw=true)](../parts/5v-unmanaged-10-100-switch.md)  | [`6V DC (4 cell) NICD battery`](../parts/LJ-6V-battery.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/LJ-6V-battery.jpg?raw=true)](../parts/LJ-6V-battery.md)  | [`6V DC charger for NICD batteries`](../parts/USB-charger-NICD-6V.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/USB-charger-NICD-6V-1.jpg?raw=true)](../parts/USB-charger-NICD-6V.md)  | [`AC switch`](../parts/ac-switch.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/ac-switch.jpg?raw=true)](../parts/ac-switch.md)  | [`AC to DC power adapter`](../parts/power-adapter.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/power-adapter.jpg?raw=true)](../parts/power-adapter.md)  | [`AC volt meter`](../parts/ac-volt-meter.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/ac-volt-meter.jpg?raw=true)](../parts/ac-volt-meter.md)  | [`Arduino Nano`](../parts/arduino-nano.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/arduino-nano.png?raw=true)](../parts/arduino-nano.md)  | [`DC circuit breaker`](../parts/dc-circuit-breaker.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/mcb-3.jpg?raw=true)](../parts/dc-circuit-breaker.md)  | [`DC fuse, ANL or MIDI type`](../parts/dc-fuse.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/dc-fuse.jpg?raw=true)](../parts/dc-fuse.md)  | [`DC power jack, 5.5 mm`](../parts/dc-power-jack.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/charger-socket.jpg?raw=true)](../parts/dc-power-jack.md)  |
| [`DC power plug, 5.5 mm`](../parts/dc-power-plug.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/charging-port.jpg?raw=true)](../parts/dc-power-plug.md)  | [`DC volt meter`](../parts/dc-volt-meter.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/dsn-vc288.jpg?raw=true)](../parts/dc-volt-meter.md)  | [`DFPlayer Mini, audio file player`](../parts/dfplayer-mini.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/dFPlayer-mini-1.png?raw=true)](../parts/dfplayer-mini.md)  | [`DSN-VC288, panel mount, 4-30 VDC, 10A (50A with shunt resistor), voltmeter ammeter`](../parts/dsn-vc288.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/dsn-vc288.jpg?raw=true)](../parts/dsn-vc288.md)  | [`GC03, recordable sound module, diymore`](../parts/gc03.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/gc03.png?raw=true)](../parts/gc03.md)  | [`Gearboxed DC Motor, 12 V (3-24 V), 3A, 120 RPM, 1:91, 15 Kg cm`](../parts/DC-gearboxed-motor-12V-120RPM.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/GM6558/01.jpg?raw=true)](../parts/DC-gearboxed-motor-12V-120RPM.md)  | [`HC-SR04: ultrasonic-sensor`](../parts/ultrasonic-sensor.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/HC-SR04.jpg?raw=true)](../parts/ultrasonic-sensor.md)  | [`HW-373, Li-Ion charger`](../parts/hw-373-charger.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/hw-373-charger.jpeg?raw=true)](../parts/hw-373-charger.md)  | [`L 1x2`](../parts/L-1x2.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/L-1x2-1.jpg?raw=true)](../parts/L-1x2.md)  | [`LED, ~2 V forward voltage, 10-20 mA`](../parts/LED.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/led.png?raw=true)](../parts/LED.md)  |
| [`Li-Ion battery charger, 12.6 VDC, 1 A`](../parts/li-ion-charger.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/power-adapter.jpg?raw=true)](../parts/li-ion-charger.md)  | [`Li-Ion battery`](../parts/li-ion-battery.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/lithium-battery.jpg?raw=true)](../parts/li-ion-battery.md)  | [`MT-3608, step up module.`](../parts/mt-3608.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/mt-3608.jpg?raw=true)](../parts/mt-3608.md)  | [`Micro USB cable`](../parts/micro-usb-cable.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/micro-usb-cable.jpg?raw=true)](../parts/micro-usb-cable.md)  | [`Ni-MH AA, 2400 mAh, 1.2 VDC`](../parts/ni-mh-battery.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/ni-mh-battery.jpg?raw=true)](../parts/ni-mh-battery.md)  | [`Polyfuse, 1.1 A hold, 2.2 A trip, 16 V, resettable, through-hole, e.g., MF-R110`](../parts/Polyfuse.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/polyfuse.png?raw=true)](../parts/Polyfuse.md)  | [`RJ-45, Cat5e or Cat6`](../parts/ethernet-cable.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/ethernet-cable.jpeg?raw=true)](../parts/ethernet-cable.md)  | [`Raspberry Pi Camera, V1.3`](../parts/rpi-camera.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/rpi-camera.jpg?raw=true)](../parts/rpi-camera.md)  | [`Raspberry Pi.`](../parts/rpi.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/rpi3bplus.png?raw=true)](../parts/rpi.md)  | [`Rechargeable sealed lead acid battery`](../parts/SLA-Battery.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/battery.png?raw=true)](../parts/SLA-Battery.md)  |
| [`Resistor, 1/4 watt, 5% tolerance`](../parts/resistor.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/resistor.png?raw=true)](../parts/resistor.md)  | [`SD card, 32 GB`](../parts/sd-card-32-gb.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/sd-card-32-gb.jpg?raw=true)](../parts/sd-card-32-gb.md)  | [`SX1276/77/78/79 UART`](../parts/sx1276.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/sx1276-1.jpg?raw=true)](../parts/sx1276.md)  | [`TB6612, 2-channel DC motor driver.`](../parts/tb6612.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/tb6612.jpg?raw=true)](../parts/tb6612.md)  | [`TV bracket`](../parts/TV-bracket.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/tv-bracket.jpeg?raw=true)](../parts/TV-bracket.md)  | [`TVS diode, unidirectional, 600 W, 6.8 V clamp, e.g. P6KE6.8A, DO-15 package`](../parts/TVS-diode.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/TVSdiode.png?raw=true)](../parts/TVS-diode.md)  | [`TV`](../parts/TV.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/tv.jpg?raw=true)](../parts/TV.md)  | [`XL4015: 8 - 36 VDC -> 1.25 - 32 VDC, 5A`](../parts/XL4015.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/XL4015.png?raw=true)](../parts/XL4015.md)  | [`auto power connectors`](../parts/connector.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/connector.jpg?raw=true)](../parts/connector.md)  | [`brushless drive, 36 - 48 V DC, 350 W, sine wave, silent`](../parts/brushless-350w-drive.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/brushless-350w-drive.jpg?raw=true)](../parts/brushless-350w-drive.md)  |
| [`capacitor, 470 μF to 1000 μF, 16 V or 25 V, Electrolytic, 105 °C rated if possible.`](../parts/470-mF.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/capacitor.png?raw=true)](../parts/470-mF.md)  | [`ceramic terminal`](../parts/ceramic-terminal.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/ceramic-terminal.jpg?raw=true)](../parts/ceramic-terminal.md)  | [`double-sided PCB, 9 cm x 7 cm`](../parts/PCB-double-9x7.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/PCB-double-9x7.jpeg?raw=true)](../parts/PCB-double-9x7.md)  | [`double-sided tape.`](../parts/double-sided-tape.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/double-sided-tape.jpg?raw=true)](../parts/double-sided-tape.md)  | [`dupont cables, female to female`](../parts/dupont-cables.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/dupont-cables.jpg?raw=true)](../parts/dupont-cables.md)  | [`electrical tape`](../parts/electrical-tape.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/electrical-tape.jpg?raw=true)](../parts/electrical-tape.md)  | [`emergency stop switch`](../parts/emergency-stop.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/emergency-stop.jpg?raw=true)](../parts/emergency-stop.md)  | [`front connector`](../parts/front-connector.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/front-connector.jpg?raw=true)](../parts/front-connector.md)  | [`front wheels`](../parts/front-wheels.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/front-wheels.jpg?raw=true)](../parts/front-wheels.md)  | [`gearboxed DC motor, 6V DC`](../parts/yellow-gearbox-dc-motor.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/yellow-gearbox-dc-motor.png?raw=true)](../parts/yellow-gearbox-dc-motor.md)  |
| [`gen1-s blue bracket`](../parts/gen1-s-blue-bracket.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/gen1-s.png?raw=true)](../parts/gen1-s-blue-bracket.md)  | [`green terminal`](../parts/green-terminal.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/green-terminal.jpg?raw=true)](../parts/green-terminal.md)  | [`hdmi cable`](../parts/hdmi-cable.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/hdmi-cable.jpg?raw=true)](../parts/hdmi-cable.md)  | [`heater element`](../parts/heater-element.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/heater-element.jpg?raw=true)](../parts/heater-element.md)  | [`heavy duty pipe clamp`](../parts/heavy-duty-pipe-clamp.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/heavy-duty-pipe-clamp.jpg?raw=true)](../parts/heavy-duty-pipe-clamp.md)  | [`keyboard`](../parts/keyboard.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/keyboard.jpg?raw=true)](../parts/keyboard.md)  | [`micro hdmi adapter`](../parts/micro-hdmi-adapter.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/micro-hdmi-adapter.jpg?raw=true)](../parts/micro-hdmi-adapter.md)  | [`miniature circuit breaker (MCB)`](../parts/mcb.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/mcb-3.jpg?raw=true)](../parts/mcb.md)  | [`mountable digital thermometer`](../parts/mountable-digital-thermometer.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/mountable-digital-thermometer.jpeg?raw=true)](../parts/mountable-digital-thermometer.md)  | [`numpad`](../parts/numpad.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/numpad.jpg?raw=true)](../parts/numpad.md)  |
| [`nuts, bolts, and spacers`](../parts/nuts-bolts-spacers.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/nuts-bolts-spacers.jpg?raw=true)](../parts/nuts-bolts-spacers.md)  | [`on/off DC switch with indicator led`](../parts/dc-switch.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/on-off-switch.png?raw=true)](../parts/dc-switch.md)  | [`passive speaker`](../parts/speaker.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/speaker.png?raw=true)](../parts/speaker.md)  | [`pin headers`](../parts/pin-headers.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/pin-headers.jpg?raw=true)](../parts/pin-headers.md)  | [`plexiglass, 2 mm or 2.5 mm thickness`](../parts/plexiglass.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/plexiglass.jpg?raw=true)](../parts/plexiglass.md)  | [`power inverter, 12 VDC -> 220 VAC.`](../parts/power-inverter.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/power-inverter.jpg?raw=true)](../parts/power-inverter.md)  | [`power wheel wheels`](../parts/wheel.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/wheel1.jpg?raw=true)](../parts/wheel.md)  | [`push button`](../parts/pushbutton.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/pushbutton.png?raw=true)](../parts/pushbutton.md)  | [`pwm manual DC motor controller, 12 V, ≥ 5 A`](../parts/pwm-manual-dc-motor-controller.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/pwm-manual-dc-motor-controller.jpg?raw=true)](../parts/pwm-manual-dc-motor-controller.md)  | [`relay`](../parts/relay.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/relay.jpg?raw=true)](../parts/relay.md)  |
| [`resistance heating wire`](../parts/resistance-heating-wire.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/resistance-heating-wire.jpg?raw=true)](../parts/resistance-heating-wire.md)  | [`safety fuse`](../parts/safety-fuse.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/safety-fuse.jpg?raw=true)](../parts/safety-fuse.md)  | [`shaft, 10 cm`](../parts/shaft-10cm.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/shaft-10cm.jpg?raw=true)](../parts/shaft-10cm.md)  | [`single-sided PCB, 14 cm x 9.5 cm`](../parts/PCB-single-14x9_5.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/pcb-14x9_5cm.jpg?raw=true)](../parts/PCB-single-14x9_5.md)  | [`small on/off switch`](../parts/small-dc-switch.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/small-on-off-switch.jpg?raw=true)](../parts/small-dc-switch.md)  | [`solid cable 1-1.5 mm^2`](../parts/solid-cable-1-15.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/solid-cable-1-15.jpg?raw=true)](../parts/solid-cable-1-15.md)  | [`strong thread`](../parts/strong-thread.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/strong-thread.jpg?raw=true)](../parts/strong-thread.md)  | [`template`](../parts/template.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/template.jpg?raw=true)](../parts/template.md)  | [`the swallow shield`](../parts/swallow-shield.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/swallow-3d.png?raw=true)](../parts/swallow-shield.md)  | [`wheels for gearboxed DC motor`](../parts/yellow-wheels.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/yellow-wheels.jpg?raw=true)](../parts/yellow-wheels.md)  |
| [`white terminal`](../parts/white-terminal.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/white-terminal.jpg?raw=true)](../parts/white-terminal.md)  |  |  |  |  |  |  |  |  |  |

1. [12 VDC motor, 20-45 W](./dc-motor-12-VDC-45W.md).
1. [16 AWG wire](./16-awg-wire.md).
1. [1N4148 diode](./1N4148.md).
1. [2 x AA battery holder](./2xAA-battery-holder.md).
1. [220VAC dimmer](./220VAC-dimmer.md).
1. [36V DC hub motor, 350 W, front, no gearbox](./36v-hub-motor.md).
1. [4 x AA battery holder](./4xAA-battery-holder.md).
1. [4-channel transmitter and receiver](./4-ch-transceiver.md).
1. [43 A, H-Bridge Motor Driver](./BTS7960.md).
1. [433 MHz SMA whip antenna (small stubby or ~10–20 cm) or U.FL -> SMA pigtail if the module has a tiny U.FL connector.](./whip-antenna.md).
1. [5V unmanaged 10/100 switch](./5v-unmanaged-10-100-switch.md).
1. [6V DC (4 cell) NICD battery](./LJ-6V-battery.md).
1. [6V DC charger for NICD batteries](./USB-charger-NICD-6V.md).
1. [AC switch](./ac-switch.md).
1. [AC to DC power adapter](./power-adapter.md).
1. [AC volt meter](./ac-volt-meter.md).
1. [Arduino Nano](./arduino-nano.md).
1. [DC circuit breaker](./dc-circuit-breaker.md).
1. [DC fuse, ANL or MIDI type](./dc-fuse.md).
1. [DC power jack, 5.5 mm](./dc-power-jack.md).
1. [DC power plug, 5.5 mm](./dc-power-plug.md).
1. [DC volt meter](./dc-volt-meter.md).
1. [DFPlayer Mini, audio file player](./dfplayer-mini.md).
1. [DSN-VC288, panel mount, 4-30 VDC, 10A (50A with shunt resistor), voltmeter ammeter](./dsn-vc288.md).
1. [GC03, recordable sound module, diymore](./gc03.md).
1. [Gearboxed DC Motor, 12 V (3-24 V), 3A, 120 RPM, 1:91, 15 Kg cm](./DC-gearboxed-motor-12V-120RPM.md).
1. [HC-SR04: ultrasonic-sensor](./ultrasonic-sensor.md).
1. [HW-373, Li-Ion charger](./hw-373-charger.md).
1. [L 1x2](./L-1x2.md).
1. [LED, ~2 V forward voltage, 10-20 mA](./LED.md).
1. [Li-Ion battery charger, 12.6 VDC, 1 A](./li-ion-charger.md).
1. [Li-Ion battery](./li-ion-battery.md).
1. [MT-3608, step up module.](./mt-3608.md).
1. [Micro USB cable](./micro-usb-cable.md).
1. [Ni-MH AA, 2400 mAh, 1.2 VDC](./ni-mh-battery.md).
1. [Polyfuse, 1.1 A hold, 2.2 A trip, 16 V, resettable, through-hole, e.g., MF-R110](./Polyfuse.md).
1. [RJ-45, Cat5e or Cat6](./ethernet-cable.md).
1. [Raspberry Pi Camera, V1.3](./rpi-camera.md).
1. [Raspberry Pi.](./rpi.md).
1. [Rechargeable sealed lead acid battery](./SLA-Battery.md).
1. [Resistor, 1/4 watt, 5% tolerance](./resistor.md).
1. [SD card, 32 GB](./sd-card-32-gb.md).
1. [SX1276/77/78/79 UART](./sx1276.md).
1. [TB6612, 2-channel DC motor driver.](./tb6612.md).
1. [TV bracket](./TV-bracket.md).
1. [TVS diode, unidirectional, 600 W, 6.8 V clamp, e.g. P6KE6.8A, DO-15 package](./TVS-diode.md).
1. [TV](./TV.md).
1. [XL4015: 8 - 36 VDC -> 1.25 - 32 VDC, 5A](./XL4015.md).
1. [auto power connectors](./connector.md).
1. [brushless drive, 36 - 48 V DC, 350 W, sine wave, silent](./brushless-350w-drive.md).
1. [capacitor, 470 μF to 1000 μF, 16 V or 25 V, Electrolytic, 105 °C rated if possible.](./470-mF.md).
1. [ceramic terminal](./ceramic-terminal.md).
1. [double-sided PCB, 9 cm x 7 cm](./PCB-double-9x7.md).
1. [double-sided tape.](./double-sided-tape.md).
1. [dupont cables, female to female](./dupont-cables.md).
1. [electrical tape](./electrical-tape.md).
1. [emergency stop switch](./emergency-stop.md).
1. [front connector](./front-connector.md).
1. [front wheels](./front-wheels.md).
1. [gearboxed DC motor, 6V DC](./yellow-gearbox-dc-motor.md).
1. [gen1-s blue bracket](./gen1-s-blue-bracket.md).
1. [green terminal](./green-terminal.md).
1. [hdmi cable](./hdmi-cable.md).
1. [heater element](./heater-element.md).
1. [heavy duty pipe clamp](./heavy-duty-pipe-clamp.md).
1. [keyboard](./keyboard.md).
1. [micro hdmi adapter](./micro-hdmi-adapter.md).
1. [miniature circuit breaker (MCB)](./mcb.md).
1. [mountable digital thermometer](./mountable-digital-thermometer.md).
1. [numpad](./numpad.md).
1. [nuts, bolts, and spacers](./nuts-bolts-spacers.md).
1. [on/off DC switch with indicator led](./dc-switch.md).
1. [passive speaker](./speaker.md).
1. [pin headers](./pin-headers.md).
1. [plexiglass, 2 mm or 2.5 mm thickness](./plexiglass.md).
1. [power inverter, 12 VDC -> 220 VAC.](./power-inverter.md).
1. [power wheel wheels](./wheel.md).
1. [push button](./pushbutton.md).
1. [pwm manual DC motor controller, 12 V, ≥ 5 A](./pwm-manual-dc-motor-controller.md).
1. [relay](./relay.md).
1. [resistance heating wire](./resistance-heating-wire.md).
1. [safety fuse](./safety-fuse.md).
1. [shaft, 10 cm](./shaft-10cm.md).
1. [single-sided PCB, 14 cm x 9.5 cm](./PCB-single-14x9_5.md).
1. [small on/off switch](./small-dc-switch.md).
1. [solid cable 1-1.5 mm^2](./solid-cable-1-15.md).
1. [strong thread](./strong-thread.md).
1. [template](./template.md).
1. [the swallow shield](./swallow-shield.md).
1. [wheels for gearboxed DC motor](./yellow-wheels.md).
1. [white terminal](./white-terminal.md).
